==> haskell-http-download-0.2.1.0-197-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-ESqtrfdhW3uEc1y9o18WkO
key:                  http-download-0.2.1.0-ESqtrfdhW3uEc1y9o18WkO
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  fe32cf85a01bfc8a56791789e8960ef0
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-ESqtrfdhW3uEc1y9o18WkO
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-9p4vtkAuTQ4GHdtuHWxZHU
    bytestring-0.11.5.3 conduit-1.3.6.1-GHyJy0fEO4I5Y3sMB26bfT
    conduit-extra-1.3.7-IZqbdwWCIVBKlmFf1WuGHS
    crypton-1.0.0-DPZJlEmcVd8Aodr5WBuA08
    crypton-conduit-0.2.3-7YlKBMO6IY6IPN36R2epx2 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-0.7.18-163W4AHWMZxiWwErxEeuv
    http-conduit-2.3.9.1-G9skUe0R0eKFLtgtZaUIye
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    path-0.9.5-3cta3v6XNU1LQ20l3qbSA1
    path-io-1.8.2-I95UZMHfEdj6qJgYoqe4Cs
    retry-0.9.3.1-2kYHOCjSs9LBKcjNRahL80
    rio-0.1.22.0-J3Jrfq68YWeKEgCNothzNm
    rio-prettyprint-0.1.7.0-4bsq76DyoNoJrSlIhRk0r6

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-download-0.2.1.0-198-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-7sgYoJseogo838ychWHpo7
key:                  http-download-0.2.1.0-7sgYoJseogo838ychWHpo7
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  725174b49c4c64d0b328d067c98877db
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-7sgYoJseogo838ychWHpo7
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-8c5r2DE7WSfCyZ8FdUPHBN
    bytestring-0.11.5.3 conduit-1.3.6.1-LsCA1bXaHAtCkLdZq4D2B7
    conduit-extra-1.3.7-4d3La7fX0JzEswaYVufsQY
    crypton-1.0.0-F2pWGT0NRMlASY0hjjaDVz
    crypton-conduit-0.2.3-IpSPpPwUmSW5ff2DNC6Lwa directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-0.7.18-K4RY5DI3fa89LS1a2A03GX
    http-conduit-2.3.9.1-KSzVopJIkMUDWWEoBzLNsW
    http-types-0.12.4-1ct1dd8yFZbHBxvHAGckYw
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    path-0.9.5-va9N1QK81lCOUVGQf4trY
    path-io-1.8.2-CqxULpK3gxLK0zLbjfyNam
    retry-0.9.3.1-LvfQKbZhf04FUZ2N5kL1J9
    rio-0.1.22.0-LLKrv0KIdQYECZD0YAuEXT
    rio-prettyprint-0.1.7.0-54MwP0OYWRnAyGC1bwBeGx

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
